@@ -30,7 +30,7 @@ class EventMembersSyncDataCheck(DataCheck):
         async_events = []
         for event in Event.objects.all():
             if not set(event.linked_group.members.values_list("id", flat=True)) == set(
-                event.registrations.values_list("person", flat=True)
+                event.registrations.filter(retracted=False).values_list("person", flat=True)
             ):
                 async_events.append(event)
 
