@@ -11,13 +11,13 @@ from .models import Event, EventRegistration, Terms, Voucher
 class EventRegistrationFilter(FilterSet):
     class Meta:
         model = EventRegistration
-        fields = ["person", "event", "date_registered", "states"]
+        fields = ["person", "event", "date_registered", "states", "retracted"]
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
         self.form.layout = Layout(
-            Row("person", "event", "states"),
+            Row("person", "event", "states", "retracted"),
             Row("date_registered"),
         )
 
