@@ -63,7 +63,7 @@ class InfoMailing(ExtensibleModel):
             through = EventInfoMailingThrough.objects.get(info_mailing=self, event=event)
             sent_to = through.sent_to.all()
 
-            for registration in event.registrations.all():
+            for registration in event.registrations.filter(retracted=False):
                 if registration.person in sent_to:
                     continue
 
@@ -148,7 +148,9 @@ class Event(ExtensibleModel):
         return self.display_name
 
     def sync_group_members(self):
-        self.linked_group.members.set(self.registrations.values_list("person", flat=True))
+        self.linked_group.members.set(
+            self.registrations.filter(retracted=False).values_list("person", flat=True)
+        )
 
     def can_register(self, request=None):
         now = datetime.today().date()
@@ -280,6 +282,17 @@ class EventRegistration(ExtensibleModel):
         RegistrationState, verbose_name=_("States"), related_name="registrations"
     )
 
+    retracted = models.BooleanField(verbose_name=_("Retracted"), default=False)
+    retracted_date = models.DateField(verbose_name=_("Retracted at"), null=True, blank=True)
+
+    def retract(self):
+        # Remove person from group
+        self.event.linked_group.members.remove(self.person)
+        # Mark registration as retracted
+        self.retracted = True
+        self.retracted_date = datetime.today()
+        self.save()
+
     def get_person(self):
         return self.person
 
