@@ -16,7 +16,7 @@ def is_own_voucher(user: User, obj: Voucher) -> bool:
 
 
 @predicate
-def is_own_registration(user: User, registration: EventRegistration) -> bool:
+def is_own_registration(user: User, obj: EventRegistration) -> bool:
     """Predicate which checks if the registration belongs to the user."""
     return obj.person == user.person
 
