@@ -1,4 +1,4 @@
-import rules
+import rules;
 
 from aleksis.core.util.predicates import (
     has_any_object,
@@ -65,6 +65,10 @@ view_event_predicate = (
 )
 rules.add_perm("paweljong.view_event_rule", view_event_predicate)
 
+# Event organiser view
+view_event_detail_predicate = (has_person & is_organiser)
+rules.add_perm("paweljong.view_event_detail_rule", view_event_detail_predicate)
+
 # Delete event
 delete_event_predicate = has_person & (
     has_global_perm("paweljong.delete_event") | has_object_perm("paweljong.delete_event")
@@ -224,3 +228,6 @@ can_view_menu_predicate = has_person & (
     | view_registration_states_predicate
 )
 rules.add_perm("paweljong.view_menu", can_view_menu_predicate)
+
+can_retract_registration_predicate = has_person & (is_organiser)
+rules.add_perm("paweljong.can_retract_registration_rule", can_retract_registration_predicate)
