@@ -20,9 +20,17 @@ class ManageEventsTable(tables.Table):
         verbose_name=_("Edit"),
         text=_("Edit"),
     )
-    view = tables.LinkColumn(
+
+    view_public = tables.LinkColumn(
         "event_by_name",
         args=[A("slug")],
+        verbose_name=_("Public page"),
+        text=_("Public page"),
+    )
+
+    view = tables.LinkColumn(
+        "event_detail_by_name",
+        args=[A("slug")],
         verbose_name=_("View"),
         text=_("View"),
     )
@@ -58,6 +66,7 @@ class EventRegistrationsTable(tables.Table):
     event = tables.Column()
     date_registered = tables.Column()
     states = tables.Column()
+    retracted = tables.Column()
     view = tables.LinkColumn(
         "registration_by_pk",
         args=[A("id")],
@@ -126,3 +135,27 @@ class RegistrationStatesTable(tables.Table):
     def render_name(self, value, record):
         context = dict(state=record)
         return render_to_string("paweljong/registration_state/chip.html", context)
+
+
+class ChildGroupsTable(tables.Table):
+    """Table to list groups."""
+
+    class Meta:
+        attrs = {"class": "highlight"}
+
+    name = tables.LinkColumn("group_by_id", args=[A("id")])
+    short_name = tables.LinkColumn("group_by_id", args=[A("id")])
+
+    add_persons = tables.LinkColumn(
+        "add_persons_to_group",
+        args=[A("id")],
+        verbose_name=_("Add persons"),
+        text=_("Add persons"),
+    )
+
+
+class AdditionalFieldsTable(tables.Table):
+    class Meta:
+        attrs = {"class": "highlight"}
+
+    title = tables.LinkColumn("edit_additional_field_by_id", args=[A("id")])
