@@ -42,7 +42,13 @@ urlpatterns = [
         views.RegisterEventWizardView.as_view(register_forms, condition_dict=condition_dict),
         name="register_event_by_slug",
     ),
+    path(
+        "group_persons/<int:pk>/add",
+        views.PersonGroupView.as_view(),
+        name="add_persons_to_group",
+    ),
     path("event/<slug:slug>", views.EventFullView.as_view(), name="event_by_name"),
+    path("event/<slug:slug>/detail", views.EventDetailView.as_view(), name="event_detail_by_name"),
     path(
         "event/<slug:slug>/start",
         views.RegisterEventStart.as_view(),
@@ -71,7 +77,11 @@ urlpatterns = [
     path("vouchers/<int:pk>/print", views.print_voucher, name="print_voucher_by_pk"),
     path("vouchers/", views.vouchers, name="vouchers"),
     path("event/lists/generate", views.generate_lists, name="generate_lists"),
-    path("event/registrations/list", views.registrations, name="registrations"),
+    path(
+        "event/registrations/<int:pk>/retract",
+        views.RetractRegistration.as_view(),
+        name="retract_registration_by_pk",
+    ),
     path(
         "event/registrations/<int:pk>",
         views.EventRegistrationDetailView.as_view(),
