@@ -11,7 +11,7 @@ from django.utils.decorators import method_decorator
 from django.utils.text import slugify
 from django.utils.translation import ugettext as _
 from django.views.decorators.cache import never_cache
-from django.views.generic import FormView, TemplateView
+from django.views.generic import FormView, TemplateView, View
 from django.views.generic.detail import DetailView
 
 import reversion
@@ -24,12 +24,11 @@ from templated_email import send_templated_mail
 
 from aleksis.apps.postbuero.models import MailAddress
 from aleksis.core.mixins import AdvancedCreateView, AdvancedDeleteView, AdvancedEditView
-from aleksis.core.models import Activity, Person
+from aleksis.core.models import Activity, Group, Person
 from aleksis.core.util import messages
 from aleksis.core.util.core_helpers import get_site_preferences, objectgetter_optional
-from aleksis.core.util.predicates import queryset_rules_filter
 
-from .filters import EventFilter, EventRegistrationFilter, VoucherFilter
+from .filters import EventFilter, VoucherFilter
 from .forms import (
     EditEventForm,
     EditEventRegistrationForm,
@@ -37,11 +36,14 @@ from .forms import (
     EditTermForm,
     EditVoucherForm,
     GenerateListForm,
+    PersonGroupFormPerson,
     RegistrationNotificationForm,
     RegistrationStatesForm,
 )
 from .models import Event, EventRegistration, InfoMailing, RegistrationState, Terms, Voucher
 from .tables import (
+    AdditionalFieldsTable,
+    ChildGroupsTable,
     EventRegistrationsTable,
     InfoMailingsTable,
     ManageEventsTable,
@@ -135,28 +137,6 @@ def generate_lists(request: HttpRequest) -> HttpResponse:
     return render(request, "paweljong/print/manage.html", context)
 
 
-@permission_required("paweljong.view_registrations_rule")
-def registrations(request: HttpRequest) -> HttpResponse:
-    """List view listing all registrations."""
-    context = {}
-
-    # Get all registrations
-    registrations = queryset_rules_filter(
-        request.user, EventRegistration.objects.all(), "paweljong.view_registration_rule"
-    )
-
-    # Get filter
-    registrations_filter = EventRegistrationFilter(request.GET, queryset=registrations)
-    context["registrations_filter"] = registrations_filter
-
-    # Build table
-    registrations_table = EventRegistrationsTable(registrations_filter.qs)
-    RequestConfig(request).configure(registrations_table)
-    context["registrations_table"] = registrations_table
-
-    return render(request, "paweljong/event_registration/list.html", context)
-
-
 @method_decorator(never_cache, name="dispatch")
 class EventRegistrationCreateView(PermissionRequiredMixin, AdvancedCreateView):
     """Create view for event registrations."""
@@ -899,3 +879,76 @@ class RegistrationStateEditView(PermissionRequiredMixin, AdvancedEditView):
     template_name = "paweljong/registration_state/edit.html"
     success_url = reverse_lazy("registration_states")
     success_message = _("The term has been saved.")
+
+
+class RetractRegistration(PermissionRequiredMixin, View):
+
+    permission_required = "paweljong.can_retract_registration_rule"
+
+    def get(self, *args, **kwargs):
+        registration = EventRegistration.objects.get(id=self.kwargs["pk"])
+
+        registration.retract()
+        messages.success(self.request, _("Registration successfully retracted."))
+
+        return redirect("registrations")
+
+
+class EventDetailView(PermissionRequiredMixin, DetailView):
+    """Detail view for an event instance."""
+
+    context_object_name = "event"
+    permission_required = "paweljong.view_event_detail_rule"
+    template_name = "paweljong/event/detail.html"
+    model = Event
+    slug_field = "slug"
+
+    def get_queryset(self):
+        return Event.objects.all()
+
+    def get_context_data(self, **kwargs):
+
+        context = super().get_context_data(**kwargs)
+
+        # Registrations table
+        registrations = EventRegistration.objects.filter(event=self.object)
+        registrations_table = EventRegistrationsTable(registrations)
+        RequestConfig(self.request).configure(registrations_table)
+        context["registrations_table"] = registrations_table
+
+        # Child groups table
+        child_groups = self.object.linked_group.child_groups.all()
+        child_groups_table = ChildGroupsTable(child_groups)
+        RequestConfig(self.request).configure(child_groups_table)
+        context["child_groups_table"] = child_groups_table
+
+        # Additional fields table
+        additional_fields = self.object.linked_group.additional_fields.all()
+        additional_fields_table = AdditionalFieldsTable(additional_fields)
+        RequestConfig(self.request).configure(additional_fields_table)
+        context["additional_fields_table"] = additional_fields_table
+
+        return context
+
+
+class PersonGroupView(PermissionRequiredMixin, FormView):
+
+    template_name = "paweljong/event/persons_group.html"
+    permission_required = "paweljong.add_persons_to_group_rule"
+    form_class = PersonGroupFormPerson
+
+    def form_valid(self, form):
+
+        group = Group.objects.get(id=self.kwargs["pk"])
+
+        try:
+            person = Person.objects.get(user__username=form.cleaned_data["username"])
+            group.members.add(person)
+            messages.success(self.request, _(f"Person {person} added successfully!"))
+        except Person.DoesNotExist:
+            messages.error(self.request, _("Person does not exist!"))
+
+        return super().form_valid(self)
+
+    def get_success_url(self):
+        return reverse("add_persons_to_group", kwargs={"pk": self.kwargs["pk"]})
